@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-form
 version: 1.4.6
-id: yesod-form-1.4.6-33df701f6ce354a3ae16e9cd594ae06c
-key: yesod_FDoNGBO8FNbKosUVm0wTFe
+id: yesod-form-1.4.6-e87deb06856da3fa0104c0eca2c57620
+key: yesod_LuWx9u8XOohCqgQ8jliDxw
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -27,10 +27,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-form-1.4.6
-hs-libraries: HSyesod-form-1.4.6-FDoNGBO8FNbKosUVm0wTFe
+hs-libraries: HSyesod-form-1.4.6-LuWx9u8XOohCqgQ8jliDxw
 depends:
-    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
-    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
@@ -39,20 +39,20 @@ depends:
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
-    email-validate-2.2.0-1d0bdf1134278e653ef5708bdf20b516
+    email-validate-2.2.0-ae0abf871e42011586547a4481d3ce69
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    persistent-2.2.4.1-2b50a3e9b6124bb06f6361c04fb03b63
+    persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-d65cfe041713246ebadd86a7511ba6cd
+    shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    xss-sanitize-0.3.5.6-15ce834c551f8ea378314111ffb33296
-    yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
-    yesod-persistent-1.4.0.3-8395aca265c8d812b1837a7679a2306f
+    xss-sanitize-0.3.5.6-b3b679ace14b1ead6abf3b67e5cfe55e
+    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
+    yesod-persistent-1.4.0.3-ca84b6eb145e15f51b714d496323d807
 haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
 haddock-html: /usr/share/doc/haskell-yesod-form/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
